package com.jeethink.receive.service;

import com.jeethink.bean.domain.ArchivesMaster;
import com.jeethink.receive.vo.ArchivesVO;
import org.apache.ibatis.annotations.Param;

import java.util.HashMap;
import java.util.List;

public interface IArchivesService {
    /**
     * 获取档案列表
     * @param archives
     * @return
     */
    List<ArchivesMaster> selectArchivesList(ArchivesMaster archives);

    /**
     * 获取档案详情
     * @param archivesId
     * @return
     */
    ArchivesVO selectArchivesById(String archivesId);

    /**
     * 新增档案
     * @param archives
     */
    void insertArchives(ArchivesVO archives);

    /**
     * 修改档案
     * @param archives
     */
    void updateArchives(ArchivesVO archives);

    /**
     * 提交档案
     * @param archives
     */
    void submitArchives(ArchivesVO archives);

    /**
     * 撤销提交
     * @param archivesId
     */
    void revocationArchives(String archivesId);

    /**
     * 删除档案
     * @param archivesId
     * @return
     */
    int removeArchives(String archivesId);

    /**
     * 修改档案状态
     * @param archivesId
     * @param nowStatus
     */
    void changeNowStatus(String archivesId, String nowStatus);

    void uploadArchiveFileList();

    String importArchives(List<ArchivesMaster> archivesMasterList, boolean updateSupport);
    String importArchives2(List<ArchivesMaster> archivesMasterList, boolean updateSupport);

    ArchivesMaster selectById(String archivesId);

    String selectArchiveFileId(@Param("userNumber") String userNumber, @Param("type") String type);

    List<HashMap> selectArchivesFileById(String archivesId);
}
